//
//	Simple test GUI
//

#include "MyGui.h"
ClassImp(MyMainFrame);


//______________________________________________________________________________
MyMainFrame::MyMainFrame(const TGWindow *p, UInt_t w, UInt_t h, UInt_t rows, UInt_t cols) : TGMainFrame(p,w,h) {
	fW		= w;
	fH		= h;
	fRows	= rows;
	fCols	= cols;
	std::cout.precision(3);
	SetCleanup(kDeepCleanup);
	Connect("ProcessedEvent(Event_t*)","MyMainFrame",this,"GUIResized()");
	Connect("CloseWindow()", "MyMainFrame", this, "CloseWindow()");
	SetWindowName("Simple test GUI");

	SetLayoutManager( new TGTableLayout(this, fRows, fCols, true, 1, kLHintsExpandX | kLHintsExpandY) ); // kLHintsCenterX | kLHintsCenterY) );

	fImg = TImage::Open("rose512.jpg");
	fImg->SetConstRatio(false);

	UInt_t width  = fW/fCols;
	UInt_t height = fH/fRows;
	TString name;
	for (UShort_t row = 0; row < fRows; row++){
		for (UShort_t col = 0; col < fCols; col++){
			name = "Canvas";
			name += row*fCols+col+1;
			fEmbCanvasVec.push_back(new TRootEmbeddedCanvas(name, this, width, height, kFixedSize, TColor::Number2Pixel(kBlack)));
			AddFrame(fEmbCanvasVec.back(), new TGTableLayoutHints(col, col+1, row, row+1));
			fEmbCanvasVec.back()->GetCanvas()->SetFillColor(kOrange);
			fEmbCanvasVec.back()->GetCanvas()->SetMargin(0.02,0.02,0.02,0.02);
			fImg->Draw();
			fEmbCanvasVec.back()->GetCanvas()->Update();

			fEmbCanvasVec.back()->SetAutoFit(false);

			fEmbCanvasVec.back()->GetViewPort()->SetBackgroundColor(TColor::Number2Pixel(kRed));
//			fEmbCanvasVec.back()->GetViewPort()->ChangeOptions(kFixedSize);

			fEmbCanvasVec.back()->GetViewPort()->GetContainer()->SetBackgroundColor(TColor::Number2Pixel(kGreen));
//			fEmbCanvasVec.back()->GetViewPort()->GetContainer()->ChangeOptions(kFixedSize);

			fEmbCanvasVec.back()->GetContainer()->SetBackgroundColor(TColor::Number2Pixel(kBlue));
//			fEmbCanvasVec.back()->GetContainer()->ChangeOptions(kFixedSize);
		}
	}
	Layout();

	// Map main frame
	MapSubwindows();
	Resize(w,h);
	MapWindow();
}

//______________________________________________________________________________
void MyMainFrame::CloseWindow(){ gApplication->Terminate(); }

//______________________________________________________________________________
void MyMainFrame::GUIResized(){
	if(GetHeight() == fH && GetWidth() == fW) return;
	std::cout << "MyMainFrame::GUIResized()" << std::endl;

	fW = GetWidth();
	fH = GetHeight();
	UShort_t width	= fW/fCols;
	UShort_t height	= fH/fRows;
	UShort_t offset = 20;

	for (UInt_t CanvasIndex = 0; CanvasIndex < fEmbCanvasVec.size(); CanvasIndex++){
		fEmbCanvasVec[CanvasIndex]->Resize(width,height);	// Fill out frame cell

//		fEmbCanvasVec[CanvasIndex]->GetViewPort()->SetPos(fEmbCanvasVec[CanvasIndex]->GetViewPort()->GetHPos()+10, fEmbCanvasVec[CanvasIndex]->GetViewPort()->GetVPos()+10);

//		fEmbCanvasVec[CanvasIndex]->GetContainer()->SetX(fEmbCanvasVec[CanvasIndex]->GetContainer()->GetX()+10);
//		fEmbCanvasVec[CanvasIndex]->GetContainer()->SetY(fEmbCanvasVec[CanvasIndex]->GetContainer()->GetY()+10);

//		fEmbCanvasVec[CanvasIndex]->GetCanvas()->SetCanvasSize(width,height/2);
//		fEmbCanvasVec.back()->GetCanvas()->Update();


//		fEmbCanvasVec[CanvasIndex]->GetViewPort()->Resize( width, height );
//		fEmbCanvasVec[CanvasIndex]->GetViewPort()->SetPos( fEmbCanvasVec[CanvasIndex]->GetViewPort()->GetHPos()+10, fEmbCanvasVec[CanvasIndex]->GetViewPort()->GetVPos()+10);
//		fEmbCanvasVec[CanvasIndex]->GetViewPort()->GetContainer()->Resize( width-offset, height-offset );
//		fEmbCanvasVec[CanvasIndex]->GetContainer()->Resize( width, height/2 );
	}
	Layout();
}

//______________________________________________________________________________
void MyGui(UShort_t rows = 2, UShort_t cols = 2){
	// pop up the GUI
	new MyMainFrame(gClient->GetRoot(), 600, 600, rows, cols);
}

int main(int argc, char **argv) {
	if( argc == 2 || argc > 3){
		std::cerr << "Usage:   " << argv[0] << " [rows cols]" << std::endl;
		return EXIT_FAILURE;
	}

	UShort_t rows = 2;
	UShort_t cols = 2;
	if (argc == 3){
		rows = std::atoi(argv[1]);
		cols = std::atoi(argv[2]);
		if( rows < 1 || cols < 1 ){
			std::cerr << "ERROR: Invalid paramters!\nUsage:   " << argv[0] << " rows cols" << std::endl;
			return EXIT_FAILURE;
		}
	}

	TApplication theApp("App",&argc,argv);
	MyGui(rows,cols);
	theApp.Run();
	return 0;
}
